.. _exceptions:

Exceptions & Warnings
=====================

.. py:module:: elasticsearch

.. autoclass:: ElasticsearchException
.. autoclass:: SerializationError
.. autoclass:: ConnectionError
.. autoclass:: ConnectionTimeout
.. autoclass:: SSLError
.. autoclass:: ApiError
   :members:
.. autoclass:: NotFoundError
.. autoclass:: ConflictError
.. autoclass:: RequestError
.. autoclass:: AuthenticationException
.. autoclass:: AuthorizationException
.. autoclass:: UnsupportedProductError

Warnings
--------

.. autoclass:: ElasticsearchWarning
